@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK   = qw(rcsv1D rcsv2D wcsv1D wcsv2D);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use Config;
 use constant NO64BITINT => ($Config{ivsize} < 8) ? 1 : 0;
@@ -494,10 +494,12 @@ sub _proc_rargs {
   $O->{reshape_inc} ||= 80_000;
   $O->{type}        ||= ($fn eq '1D' ? 'auto' : double);
   $O->{header}      ||= ($fn eq '1D' ? 'auto' : 0);
-  $O->{detect_datetime} = 1 unless defined $O->{detect_datetime};
-  if ($O->{detect_datetime} =~ /%/) {
-    $O->{strptime} = $O->{detect_datetime};
-    $O->{detect_datetime} = 1;
+  if (!NODATETIME) {
+    $O->{detect_datetime} = 1 if !defined $O->{detect_datetime};
+    if ($O->{detect_datetime} =~ /%/) {
+      $O->{strptime} = $O->{detect_datetime};
+      $O->{detect_datetime} = 1;
+    }
   }
   $O->{debug} = DEBUG unless defined $O->{debug};
 
